Changelog
=========


:Version: 1.0.2 of 2017-09-29

Minor bugfix release: some variable- and key names in batch.py still reflected 
the development name of the "CIM" model.


:Version: 1.0.1 of 2017-09-29

Fixes a link in the PyPI metadata. 


:Version: 1.0.0 of 2017-09-29

Some minor documentation and metadata changes.

:Version: 1.0-rc.1 of 2017-09-28

Refactoring for public release in pip-installable form.


:Version: [unreleased] of 2017-01-16

Begin of initial development for research.